==> ejc-bfyjerp-api-3.0.0-20250304.012156-165-sources.jar: com/ejianc/business/supply/vo/SupplyApplyVO.java <==
package com.ejianc.business.supply.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 供应商入库申请表
 * 
 * @author generator
 * 
 */
public class SupplyApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 供方编码
    private String name; // 供方名称
    private Long supplyType; // 供方类别：专业分包：major，劳务分包：labor，分包班组：sub，材料：material，设备：equipment，其他：other
    private String supplyTypeName; // 供方类别名称
    private String socialCreditCode; // 统一社会信用代码
    private String registerPlace; // 注册地
    private String registerLocation; // 注册地址
    private String businessLocation; // 经营地址
    private String supplyUrl; // 网址
    private Long registerCountryId; // 注册国家id
    private String registerCountryName; // 注册国家名称
    private String legalPerson; // 法人代表/别名
    private String legalPhone; // 法人代表电话
    private String legalMobilePhone; // 法人代表手机
    private String businessPerson; // 业务联系人
    private String businessPhone; // 业务联系人电话
    private String businessMobilePhone; // 业务联系人手机
    private Long orgId; // 所属组织id
    private String orgCode; // 所属组织编码
    private String orgName; // 所属组织名称
    private BigDecimal registeredCapital; // 注册资金
    private Long enterpriseNature; // 企业性质id
    private Long enterpriseNatureName; // 企业性质
    private String bankName; // 开户行名称
    private String bankAccount; // 户名
    private String bankCode; // 开户行卡号
    private String businessScope; // 经营范围
    private String billStateName;
    private Integer billState;
    private String memo;

    public String getBusinessLocation() {
        return businessLocation;
    }

    public void setBusinessLocation(String businessLocation) {
        this.businessLocation = businessLocation;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSupplyType() {
        return supplyType;
    }

    @ReferDeserialTransfer
    public void setSupplyType(Long supplyType) {
        this.supplyType = supplyType;
    }


    public String getSupplyTypeName() {
        return supplyTypeName;
    }

    public void setSupplyTypeName(String supplyTypeName) {
        this.supplyTypeName = supplyTypeName;
    }
    public String getSocialCreditCode() {
        return socialCreditCode;
    }

    public void setSocialCreditCode(String socialCreditCode) {
        this.socialCreditCode = socialCreditCode;
    }
    public String getRegisterPlace() {
        return registerPlace;
    }

    public void setRegisterPlace(String registerPlace) {
        this.registerPlace = registerPlace;
    }
    public String getRegisterLocation() {
        return registerLocation;
    }

    public void setRegisterLocation(String registerLocation) {
        this.registerLocation = registerLocation;
    }
    public String getSupplyUrl() {
        return supplyUrl;
    }

    public void setSupplyUrl(String supplyUrl) {
        this.supplyUrl = supplyUrl;
    }
    public Long getRegisterCountryId() {
        return registerCountryId;
    }

    public void setRegisterCountryId(Long registerCountryId) {
        this.registerCountryId = registerCountryId;
    }
    public String getRegisterCountryName() {
        return registerCountryName;
    }

    public void setRegisterCountryName(String registerCountryName) {
        this.registerCountryName = registerCountryName;
    }
    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    public String getLegalPhone() {
        return legalPhone;
    }

    public void setLegalPhone(String legalPhone) {
        this.legalPhone = legalPhone;
    }
    public String getLegalMobilePhone() {
        return legalMobilePhone;
    }

    public void setLegalMobilePhone(String legalMobilePhone) {
        this.legalMobilePhone = legalMobilePhone;
    }
    public String getBusinessPerson() {
        return businessPerson;
    }

    public void setBusinessPerson(String businessPerson) {
        this.businessPerson = businessPerson;
    }
    public String getBusinessPhone() {
        return businessPhone;
    }

    public void setBusinessPhone(String businessPhone) {
        this.businessPhone = businessPhone;
    }
    public String getBusinessMobilePhone() {
        return businessMobilePhone;
    }

    public void setBusinessMobilePhone(String businessMobilePhone) {
        this.businessMobilePhone = businessMobilePhone;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public BigDecimal getRegisteredCapital() {
        return registeredCapital;
    }

    public void setRegisteredCapital(BigDecimal registeredCapital) {
        this.registeredCapital = registeredCapital;
    }
    public Long getEnterpriseNature() {
        return enterpriseNature;
    }

    public void setEnterpriseNature(Long enterpriseNature) {
        this.enterpriseNature = enterpriseNature;
    }
    public Long getEnterpriseNatureName() {
        return enterpriseNatureName;
    }

    public void setEnterpriseNatureName(Long enterpriseNatureName) {
        this.enterpriseNatureName = enterpriseNatureName;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }
    public String getBusinessScope() {
        return businessScope;
    }

    public void setBusinessScope(String businessScope) {
        this.businessScope = businessScope;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20251216.084022-317-sources.jar: com/ejianc/business/supply/vo/SupplyApplyVO.java <==
package com.ejianc.business.supply.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 供应商入库申请表
 * 
 * @author generator
 * 
 */
public class SupplyApplyVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 供方编码
    private String name; // 供方名称
    private Long supplyType; // 供方类别：专业分包：major，劳务分包：labor，分包班组：sub，材料：material，设备：equipment，其他：other
    private String supplyTypeName; // 供方类别名称
    private String socialCreditCode; // 统一社会信用代码
    private String registerPlace; // 注册地
    private String registerLocation; // 注册地址
    private String businessLocation; // 经营地址
    private String supplyUrl; // 网址
    private Long registerCountryId; // 注册国家id
    private String registerCountryName; // 注册国家名称
    private String legalPerson; // 法人代表/别名
    private String legalPhone; // 法人代表电话
    private String legalMobilePhone; // 法人代表手机
    private String businessPerson; // 业务联系人
    private String businessPhone; // 业务联系人电话
    private String businessMobilePhone; // 业务联系人手机
    private Long orgId; // 所属组织id
    private String orgCode; // 所属组织编码
    private String orgName; // 所属组织名称
    private BigDecimal registeredCapital; // 注册资金
    private Long enterpriseNature; // 企业性质id
    private Long enterpriseNatureName; // 企业性质
    private String bankName; // 开户行名称
    private String bankAccount; // 户名
    private String bankCode; // 开户行卡号
    private String businessScope; // 经营范围
    private String billStateName;
    private Integer billState;
    private String memo;

    public String getBusinessLocation() {
        return businessLocation;
    }

    public void setBusinessLocation(String businessLocation) {
        this.businessLocation = businessLocation;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    @ReferSerialTransfer(referCode = "ejc_support_supplier_category")
    public Long getSupplyType() {
        return supplyType;
    }

    @ReferDeserialTransfer
    public void setSupplyType(Long supplyType) {
        this.supplyType = supplyType;
    }


    public String getSupplyTypeName() {
        return supplyTypeName;
    }

    public void setSupplyTypeName(String supplyTypeName) {
        this.supplyTypeName = supplyTypeName;
    }
    public String getSocialCreditCode() {
        return socialCreditCode;
    }

    public void setSocialCreditCode(String socialCreditCode) {
        this.socialCreditCode = socialCreditCode;
    }
    public String getRegisterPlace() {
        return registerPlace;
    }

    public void setRegisterPlace(String registerPlace) {
        this.registerPlace = registerPlace;
    }
    public String getRegisterLocation() {
        return registerLocation;
    }

    public void setRegisterLocation(String registerLocation) {
        this.registerLocation = registerLocation;
    }
    public String getSupplyUrl() {
        return supplyUrl;
    }

    public void setSupplyUrl(String supplyUrl) {
        this.supplyUrl = supplyUrl;
    }
    public Long getRegisterCountryId() {
        return registerCountryId;
    }

    public void setRegisterCountryId(Long registerCountryId) {
        this.registerCountryId = registerCountryId;
    }
    public String getRegisterCountryName() {
        return registerCountryName;
    }

    public void setRegisterCountryName(String registerCountryName) {
        this.registerCountryName = registerCountryName;
    }
    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }
    public String getLegalPhone() {
        return legalPhone;
    }

    public void setLegalPhone(String legalPhone) {
        this.legalPhone = legalPhone;
    }
    public String getLegalMobilePhone() {
        return legalMobilePhone;
    }

    public void setLegalMobilePhone(String legalMobilePhone) {
        this.legalMobilePhone = legalMobilePhone;
    }
    public String getBusinessPerson() {
        return businessPerson;
    }

    public void setBusinessPerson(String businessPerson) {
        this.businessPerson = businessPerson;
    }
    public String getBusinessPhone() {
        return businessPhone;
    }

    public void setBusinessPhone(String businessPhone) {
        this.businessPhone = businessPhone;
    }
    public String getBusinessMobilePhone() {
        return businessMobilePhone;
    }

    public void setBusinessMobilePhone(String businessMobilePhone) {
        this.businessMobilePhone = businessMobilePhone;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public BigDecimal getRegisteredCapital() {
        return registeredCapital;
    }

    public void setRegisteredCapital(BigDecimal registeredCapital) {
        this.registeredCapital = registeredCapital;
    }
    public Long getEnterpriseNature() {
        return enterpriseNature;
    }

    public void setEnterpriseNature(Long enterpriseNature) {
        this.enterpriseNature = enterpriseNature;
    }
    public Long getEnterpriseNatureName() {
        return enterpriseNatureName;
    }

    public void setEnterpriseNatureName(Long enterpriseNatureName) {
        this.enterpriseNatureName = enterpriseNatureName;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }
    public String getBankCode() {
        return bankCode;
    }

    public void setBankCode(String bankCode) {
        this.bankCode = bankCode;
    }
    public String getBusinessScope() {
        return businessScope;
    }

    public void setBusinessScope(String businessScope) {
        this.businessScope = businessScope;
    }
    
}
